@@ -36,6 +36,13 @@ G_BEGIN_DECLS
 typedef struct _McpAccountStorage McpAccountStorage;
 typedef struct _McpAccountStorageIface McpAccountStorageIface;
 
+#ifdef _i_used_gtk_doc_but_all_i_got_was_this_heap_of_workarounds
+/* Without this, gtk-doc doesn't generate documentation for
+ * #McpAccountStorage. There is actually no such struct: do not attempt
+ * to use it. */
+struct _McpAccountStorage { };
+#endif
+
 #define MCP_TYPE_ACCOUNT_STORAGE (mcp_account_storage_get_type ())
 
 #define MCP_ACCOUNT_STORAGE(o) \
@@ -49,7 +56,7 @@ typedef struct _McpAccountStorageIface McpAccountStorageIface;
   (G_TYPE_INSTANCE_GET_INTERFACE ((o), MCP_TYPE_ACCOUNT_STORAGE, \
                                   McpAccountStorageIface))
 
-GType mcp_account_storage_get_type (void) G_GNUC_CONST;
+GType mcp_account_storage_get_type (void);
 
 /* Virtual method implementation signatures */
 typedef gboolean (*McpAccountStorageGetFunc) (
@@ -120,49 +127,87 @@ struct _McpAccountStorageIface
   McpAccountStorageGetAdditionalInfoFunc get_additional_info;
   McpAccountStorageGetRestrictionsFunc get_restrictions;
   McpAccountStorageCreate create;
+
+  /* Since 5.15.0 */
+  gboolean (*owns) (McpAccountStorage *storage,
+      McpAccountManager *am,
+      const gchar *account);
+  gboolean (*set_attribute) (McpAccountStorage *storage,
+      McpAccountManager *am,
+      const gchar *account,
+      const gchar *attribute,
+      GVariant *val,
+      McpAttributeFlags flags);
+  gboolean (*set_parameter) (McpAccountStorage *storage,
+      McpAccountManager *am,
+      const gchar *account,
+      const gchar *parameter,
+      GVariant *val,
+      McpParameterFlags flags);
 };
 
+#ifndef __GTK_DOC_IGNORE__
+#ifndef MC_DISABLE_DEPRECATED
+
 /* functions with which to fill in the vtable */
+G_DEPRECATED_FOR (iface->priority = prio)
 void mcp_account_storage_iface_set_priority (McpAccountStorageIface *iface,
     guint prio);
 
+G_DEPRECATED_FOR (iface->name = name)
 void mcp_account_storage_iface_set_name (McpAccountStorageIface *iface,
     const gchar *name);
 
+G_DEPRECATED_FOR (iface->desc = desc)
 void mcp_account_storage_iface_set_desc (McpAccountStorageIface *iface,
     const gchar *desc);
 
+G_DEPRECATED_FOR (iface->provider = provider)
 void mcp_account_storage_iface_set_provider (McpAccountStorageIface *iface,
     const gchar *provider);
 
+G_DEPRECATED_FOR (iface->get = method)
 void mcp_account_storage_iface_implement_get (McpAccountStorageIface *iface,
     McpAccountStorageGetFunc method);
+G_DEPRECATED_FOR (iface->set = method)
 void mcp_account_storage_iface_implement_set (McpAccountStorageIface *iface,
     McpAccountStorageSetFunc method);
+G_DEPRECATED_FOR (iface->create = method)
 void mcp_account_storage_iface_implement_create (
     McpAccountStorageIface *iface,
     McpAccountStorageCreate method);
+G_DEPRECATED_FOR (iface->delete = method)
 void mcp_account_storage_iface_implement_delete (McpAccountStorageIface *iface,
     McpAccountStorageDeleteFunc method);
+G_DEPRECATED_FOR (iface->list = method)
 void mcp_account_storage_iface_implement_list (McpAccountStorageIface *iface,
     McpAccountStorageListFunc method);
+G_DEPRECATED_FOR (iface->commit = method)
 void mcp_account_storage_iface_implement_commit (McpAccountStorageIface *iface,
     McpAccountStorageCommitFunc method);
+G_DEPRECATED_FOR (iface->commit_one = method)
 void mcp_account_storage_iface_implement_commit_one (
     McpAccountStorageIface *iface,
     McpAccountStorageCommitOneFunc method);
+G_DEPRECATED_FOR (iface->ready = method)
 void mcp_account_storage_iface_implement_ready (McpAccountStorageIface *iface,
     McpAccountStorageReadyFunc method);
+G_DEPRECATED_FOR (iface->get_identifier = method)
 void mcp_account_storage_iface_implement_get_identifier (
     McpAccountStorageIface *iface,
     McpAccountStorageGetIdentifierFunc method);
+G_DEPRECATED_FOR (iface->get_additional_info = method)
 void mcp_account_storage_iface_implement_get_additional_info (
     McpAccountStorageIface *iface,
     McpAccountStorageGetAdditionalInfoFunc method);
+G_DEPRECATED_FOR (iface->get_restrictions = method)
 void mcp_account_storage_iface_implement_get_restrictions (
     McpAccountStorageIface *iface,
     McpAccountStorageGetRestrictionsFunc method);
 
+#endif /* !defined(MC_DISABLE_DEPRECATED) */
+#endif /* !defined(__GTK_DOC_IGNORE__) */
+
 /* virtual methods */
 gint mcp_account_storage_priority (const McpAccountStorage *storage);
 
@@ -220,8 +265,26 @@ const gchar *mcp_account_storage_name (const McpAccountStorage *storage);
 const gchar *mcp_account_storage_description (const McpAccountStorage *storage);
 const gchar *mcp_account_storage_provider (const McpAccountStorage *storage);
 
+gboolean mcp_account_storage_owns (McpAccountStorage *storage,
+    McpAccountManager *am,
+    const gchar *account);
+
+gboolean mcp_account_storage_set_attribute (McpAccountStorage *storage,
+    McpAccountManager *am,
+    const gchar *account,
+    const gchar *attribute,
+    GVariant *value,
+    McpAttributeFlags flags);
+gboolean mcp_account_storage_set_parameter (McpAccountStorage *storage,
+    McpAccountManager *am,
+    const gchar *account,
+    const gchar *parameter,
+    GVariant *value,
+    McpParameterFlags flags);
+
 void mcp_account_storage_emit_created (McpAccountStorage *storage,
     const gchar *account);
+G_DEPRECATED_FOR (something that is actually implemented)
 void mcp_account_storage_emit_altered (McpAccountStorage *storage,
     const gchar *account);
 void mcp_account_storage_emit_altered_one (McpAccountStorage *storage,
